var WEBBase = require("../../web.base");
var system = require("../../../system");
var settings = require("../../../../config/settings");
const axios = require("axios");

class Zzzd  extends WEBBase {
    constructor() {
        super();
        this.restClient = system.getObject("util.restClient");
        this.redisClient = system.getObject("util.redisClient");
        this.zzzApi = {
            "industryOne":"/gsb/api/industry_one",  //一级大类列表
            "industryTwo":"/gsb/api/industry_two",  //二级大类列表
            "getQualificationByIndustry":"/gsb/api/qualifications",  //根据行业ID 查询所有相关的资质
            "recommendationBusiness":"/gsb/api/recommendation_business",  //立即查看结果
            "phoneNumber":"/gsb/api/phone_number",  //免费咨询
        }
    }
    /**
     * 接口跳转-POST请求
     * action_process  执行的流程
     * action_type     执行的类型
     * action_body     执行的参数
     */
    async springBoard(pobj, qobj, req) {
        if (!pobj.actionProcess) {
            return system.getResult(null, "actionProcess参数不能为空");
        }
        if (!pobj.actionType) {
            return system.getResult(null, "actionType参数不能为空");
        }
        var result = await this.opActionProcess(pobj, pobj.actionType, req);
        return result;
    }
    async opActionProcess(pobj, action_type, req) {
        pobj.requestId = req.requestId;
        var opResult = null;
        switch (action_type) {
            case "getIndustries":  //获取一级大类列表
                try {
                    console.log(`获取一级大类列表 参数：` + JSON.stringify(pobj.actionBody));
                    let _industryOne =await this.redisClient.get("industryOne");
                    if(_industryOne){
                        opResult = system.getResult(JSON.parse(_industryOne));
                        console.log("redis数据：" + _industryOne);
                    }else{
                        opResult =await this.restPostUrl(pobj.actionBody,settings.zzzdUrl()+this.zzzApi.industryOne);
                        await this.redisClient.setWithEx("industryOne",JSON.stringify(opResult.data),45*60);
                        console.log(`获取一级大类列表 结果` + JSON.stringify(opResult));
                    }
                }catch (e) {
                    console.log(e);
                    return system.getResult(null, `系统错误`);
                }
                break;
            case "getSecondIndustries":  //获取二级大类列表
                console.log(`获取二级大类列表 参数：` + JSON.stringify(pobj.actionBody));
                if(!pobj.actionBody.industryId){
                    return system.getResult(null,`一级行业ID不能为空`)
                }
                try {
                    // await this.redisClient.delete(`industryTwo:${pobj.actionBody.industryId}`);
                    let _industryTwo =await this.redisClient.get(`industryTwo:${pobj.actionBody.industryId}`);
                    if(_industryTwo){
                        opResult = system.getResult(JSON.parse(_industryTwo));
                        console.log("redis数据：" + _industryTwo);
                    }else{
                        opResult =await this.restPostUrl(pobj.actionBody,settings.zzzdUrl()+this.zzzApi.industryTwo);
                        await this.redisClient.setWithEx(`industryTwo:${pobj.actionBody.industryId}`,JSON.stringify(opResult.data),45*60);
                        console.log(`获取二级大类列表 结果` + JSON.stringify(opResult));
                    }
                }catch (e) {
                    console.log(e);
                    return system.getResult(null, `系统错误`);
                }
                break;
            case "getQualificationByIndustry":  //根据行业获取资质
                try {
                    console.log(`根据行业获取资质 参数：` + JSON.stringify(pobj.actionBody));
                    if(!pobj.actionBody.hasOwnProperty("isImports")){
                        return system.getResult(null,`参数错误 是否进口不能为空`)
                    }
                    if(!pobj.actionBody.hasOwnProperty("storeTypeId") &&!pobj.actionBody.storeTypeId ){
                        return system.getResult(null,`参数错误 店铺类型ID不能为空`)
                    }
                    if(!pobj.actionBody.industryId){
                        return system.getResult(null,`一级行业ID不能为空`)
                    }
                    if(!pobj.actionBody.secondIndustry && pobj.actionBody.secondIndustry.length>0){
                        return system.getResult(null,`二级行业不能为空`)
                    }
                    opResult = await this.restPostUrl(pobj.actionBody,settings.zzzdUrl()+this.zzzApi.getQualificationByIndustry );
                    console.log(`根据行业获取资质 结果` + JSON.stringify(opResult));
                }catch (e) {
                    console.log(e);
                    return system.getResult(null, `系统错误`);
                }
                break;
            case "check":  //立即查看结果
                if(!pobj.actionBody.industryId){
                    return system.getResult(null,`行业ID不能为空`)
                }
                if(!pobj.actionBody.mobile){
                    return system.getResult(null, `电话不能为空`);
                }
                if(!pobj.actionBody.enterprise){
                    return system.getResult(null, `企业名称不能为空`);
                }
                if(!pobj.actionBody.data){
                    return system.getResult(null, `资质列表不能为空`);
                }
                try {
                    opResult =await this.restPostUrl(pobj.actionBody,settings.zzzdUrl()+this.zzzApi.recommendationBusiness);
                    // console.log(`根据行业获取资质 结果` + JSON.stringify(opResult));
                }catch (e) {
                    console.log(e);
                    return system.getResult(null, `系统错误` +JSON.stringify(e));
                }
                break;
            case "counselling":  //免费咨询
                if(!pobj.actionBody.id){
                    return system.getResult(null,`业务ID不能为空`)
                }
                if(!pobj.actionBody.mobile){
                    return system.getResult(null, `电话不能为空`);
                }
                pobj.actionBody.enterprise = pobj.actionBody.enterprise ? pobj.actionBody.enterprise :"";
                try {
                    console.log("免费参数"+JSON.stringify(pobj));
                    opResult = await this.restPostUrl(pobj.actionBody, settings.zzzdUrl()+this.zzzApi.phoneNumber);
                    console.log(`根据行业获取资质 结果` + JSON.stringify(opResult));
                }catch (e) {
                    console.log(e);
                    return system.getResult(null, `系统错误`);
                }
                break;
            default:
                opResult = system.getResult(null, "action_type参数错误");
                break;
        }
        return opResult;
    }

}
module.exports = Zzzd;
