const system = require("../../../system");
const AppServiceBase = require("../../app.base");
const settings = require("../../../../config/settings");
class utilsDeliverSve extends AppServiceBase{
    constructor() {
        super();
        this.centerOrderUrl = settings.centerOrderUrl();
    }

    /**
     * 参数信息重组
     * @param pobj
     * @returns {Promise<{msg: *, data, status: number}>}
     */
    async verifyParam(actionBody) {
        let verify = system.getResultSuccess();
        let deliveryData ="";
        let orderNo = "";
        let tradeStatus = '';
        let applicant ={};
        if(actionBody.delivery_content){
            deliveryData = actionBody.delivery_content[0].deliveryContent;
            orderNo = actionBody.delivery_content[0].sourceOrderNo;
        }
        if(actionBody.deliveryData){
            deliveryData = actionBody.deliveryData;
            orderNo = actionBody.orderNo;
        }
        if(deliveryData.deliveryStatusName){
            tradeStatus = deliveryData.deliveryStatusName;
        }
        if(Object.keys(deliveryData.applyUser).length ==0 || Object.keys(deliveryData.askForData).length == 0){
            tradeStatus = "待完善材料";
        }else{
            tradeStatus = "待审核";
        }
        applicant ={
            "askforId": deliveryData.apply.askforId,//申请号
            "applicantName": deliveryData.apply.applicantName, // 申请公司姓名
            "applicantType": deliveryData.apply.applicantType || '', // 申请人类型: 企业 个人
            "usccode": deliveryData.apply.usccode,//唯一社会信用代码
            "agentName": deliveryData.apply.agentName,//代理机构
            "tradeImg": deliveryData.apply.tradeImg,//商标图样
            "tradeType": deliveryData.apply.tradeType,
            "licenseAddr": deliveryData.applyUser.licenseAddr || '', // 营业执照地址
            "licenseDir": deliveryData.applyUser.licenseDir || '',//营业执照文件
            "duty": deliveryData.applyUser.duty || "", // 负责人职务
            "tel": deliveryData.applyUser.tel || "", // 联系人电话
            "addr": deliveryData.applyUser.addr || "", // 联系人地址
            "entrust": deliveryData.applyUser.entrust || "", // 代理委托书
            "country": deliveryData.applyUser.country || "", // 申请人国籍
            "dutyName": deliveryData.applyUser.dutyName || "", // 负责人姓名
            "contactsName": deliveryData.applyUser.contactsName || '', // 联系人姓名
            "email": deliveryData.applyUser.email || '', // 联系人邮箱
            "mailCode": deliveryData.applyUser.mailCode || '' // 邮政编码
        }
        let postData = {
            orderId:orderNo,
            askforId:deliveryData.apply.askforId,
            tradeType:deliveryData.apply.tradeType,
            tradeImg:deliveryData.apply.tradeImg,
            tradeStatus:tradeStatus,
            usccode:deliveryData.apply.usccode,
            agentName:deliveryData.apply.agentName,
            trademarkRejInfo:deliveryData.trademarkRejInfo,
            applicant:applicant,
            askForData:deliveryData.askForData,
            supData:deliveryData.supData
        }
        verify.data = postData;
        return verify;
    }

    /**
     * 提交复审申请单
     * @param pobj
     * @param actionBody
     * @returns {Promise<void>}
     */
    async addReviewList(pobj,actionBody){
        //参数重组
        let verifyResult = await this.verifyParam(pobj.actionBody);
        if (verifyResult.status != 0) {
            return await this.disposePushResultFail(pobj, verifyResult, "delivery->pushDelivery->verifyResult", "");
        }
        //修改交付信息
        const url = this.centerOrderUrl +"action/tmreview/springBoard";
        let result = await this.restPostUrl(pobj, url);
        if(result.status !==0){
            return system.getResult(null,'更新失败')
        }
        return result;
    }

    /**
     * 商标驳回复审控制台列表+模糊查询
     * @param pobj
     * @param actionBody
     * @returns {Promise<void>}
     */
    async getReOrderList(pobj,actionBody){
        let url = this.centerOrderUrl + "action/tmreview/springBoard";
        let result = await this.restPostUrl(pobj, url);
        return result;
    }

    /**
     * 获取官文列表
     * @param pobj
     * @param actionBody
     * @returns {Promise<void>}
     */
    async getOfficialList(pobj,actionBody){
        let url = this.centerOrderUrl + 'action/tmreview/springBoard';
        const result = await this.restPostUrl(pobj,url);
        return result;
    }

    /**
     * 接收交付中心信息
     * @returns {Promise<void>}
     */
    async receiveDeliveryInfo(pobj,actionBody){
        //修改交付信息
        const url = this.centerOrderUrl +"action/tmreview/springBoard";
        pobj.actionType = 'addReviewList';
        let result = await this.restPostUrl(pobj, url);
        if(result.status !==0){
            return system.getResult(null,result.msg)
        }
        return result;
    }
}

module.exports = utilsDeliverSve;